==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/testbase/kotlin/inputs/IntuneEnrollmentMetadataArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.testbase.kotlin.inputs

import com.pulumi.azurenative.testbase.inputs.IntuneEnrollmentMetadataArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The metadata of Intune enrollment.
 * @property appList The enrolled Intune apps.
 * @property credentialId The id of the Intune enrollment credential.
 * @property expectedDeploymentDurationInMinute The expected duration of Intune applications and policies deployment.
 */
public data class IntuneEnrollmentMetadataArgs(
    public val appList: Output<List<EnrolledIntuneAppArgs>>? = null,
    public val credentialId: Output<String>? = null,
    public val expectedDeploymentDurationInMinute: Output<Int>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.testbase.inputs.IntuneEnrollmentMetadataArgs> {
    override fun toJava(): com.pulumi.azurenative.testbase.inputs.IntuneEnrollmentMetadataArgs =
        com.pulumi.azurenative.testbase.inputs.IntuneEnrollmentMetadataArgs.builder()
            .appList(
                appList?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .credentialId(credentialId?.applyValue({ args0 -> args0 }))
            .expectedDeploymentDurationInMinute(
                expectedDeploymentDurationInMinute?.applyValue({ args0 ->
                    args0
                }),
            ).build()
}

/**
 * Builder for [IntuneEnrollmentMetadataArgs].
 */
@PulumiTagMarker
public class IntuneEnrollmentMetadataArgsBuilder internal constructor() {
    private var appList: Output<List<EnrolledIntuneAppArgs>>? = null

    private var credentialId: Output<String>? = null

    private var expectedDeploymentDurationInMinute: Output<Int>? = null

    /**
     * @param value The enrolled Intune apps.
     */
    @JvmName("witggajcuypmtojw")
    public suspend fun appList(`value`: Output<List<EnrolledIntuneAppArgs>>) {
        this.appList = value
    }

    @JvmName("kghfwrickfjtcwly")
    public suspend fun appList(vararg values: Output<EnrolledIntuneAppArgs>) {
        this.appList = Output.all(values.asList())
    }

    /**
     * @param values The enrolled Intune apps.
     */
    @JvmName("dqsjecoixhqwdhnl")
    public suspend fun appList(values: List<Output<EnrolledIntuneAppArgs>>) {
        this.appList = Output.all(values)
    }

    /**
     * @param value The id of the Intune enrollment credential.
     */
    @JvmName("stbxwjeonraashla")
    public suspend fun credentialId(`value`: Output<String>) {
        this.credentialId = value
    }

    /**
     * @param value The expected duration of Intune applications and policies deployment.
     */
    @JvmName("iiljxmbboxaffisk")
    public suspend fun expectedDeploymentDurationInMinute(`value`: Output<Int>) {
        this.expectedDeploymentDurationInMinute = value
    }

    /**
     * @param value The enrolled Intune apps.
     */
    @JvmName("ddfhmudwnaxreloj")
    public suspend fun appList(`value`: List<EnrolledIntuneAppArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.appList = mapped
    }

    /**
     * @param argument The enrolled Intune apps.
     */
    @JvmName("elxamqnqfclropwg")
    public suspend fun appList(argument: List<suspend EnrolledIntuneAppArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            EnrolledIntuneAppArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.appList = mapped
    }

    /**
     * @param argument The enrolled Intune apps.
     */
    @JvmName("dkkcbytfqhjcbndu")
    public suspend fun appList(vararg argument: suspend EnrolledIntuneAppArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            EnrolledIntuneAppArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.appList = mapped
    }

    /**
     * @param argument The enrolled Intune apps.
     */
    @JvmName("ctrctivcwvpgjhwt")
    public suspend fun appList(argument: suspend EnrolledIntuneAppArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(EnrolledIntuneAppArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.appList = mapped
    }

    /**
     * @param values The enrolled Intune apps.
     */
    @JvmName("spjcxxthquenyrrh")
    public suspend fun appList(vararg values: EnrolledIntuneAppArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.appList = mapped
    }

    /**
     * @param value The id of the Intune enrollment credential.
     */
    @JvmName("mispjujubfgoavtb")
    public suspend fun credentialId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.credentialId = mapped
    }

    /**
     * @param value The expected duration of Intune applications and policies deployment.
     */
    @JvmName("heioaaxudihvjuqk")
    public suspend fun expectedDeploymentDurationInMinute(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.expectedDeploymentDurationInMinute = mapped
    }

    internal fun build(): IntuneEnrollmentMetadataArgs = IntuneEnrollmentMetadataArgs(
        appList = appList,
        credentialId = credentialId,
        expectedDeploymentDurationInMinute = expectedDeploymentDurationInMinute,
    )
}

==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/testbase/kotlin/inputs/IntuneEnrollmentMetadataArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.testbase.kotlin.inputs

import com.pulumi.azurenative.testbase.inputs.IntuneEnrollmentMetadataArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The metadata of Intune enrollment.
 * @property appList The enrolled Intune apps.
 * @property credentialId The id of the Intune enrollment credential.
 * @property expectedDeploymentDurationInMinute The expected duration of Intune applications and policies deployment.
 */
public data class IntuneEnrollmentMetadataArgs(
    public val appList: Output<List<EnrolledIntuneAppArgs>>? = null,
    public val credentialId: Output<String>? = null,
    public val expectedDeploymentDurationInMinute: Output<Int>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.testbase.inputs.IntuneEnrollmentMetadataArgs> {
    override fun toJava(): com.pulumi.azurenative.testbase.inputs.IntuneEnrollmentMetadataArgs =
        com.pulumi.azurenative.testbase.inputs.IntuneEnrollmentMetadataArgs.builder()
            .appList(
                appList?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .credentialId(credentialId?.applyValue({ args0 -> args0 }))
            .expectedDeploymentDurationInMinute(
                expectedDeploymentDurationInMinute?.applyValue({ args0 ->
                    args0
                }),
            ).build()
}

/**
 * Builder for [IntuneEnrollmentMetadataArgs].
 */
@PulumiTagMarker
public class IntuneEnrollmentMetadataArgsBuilder internal constructor() {
    private var appList: Output<List<EnrolledIntuneAppArgs>>? = null

    private var credentialId: Output<String>? = null

    private var expectedDeploymentDurationInMinute: Output<Int>? = null

    /**
     * @param value The enrolled Intune apps.
     */
    @JvmName("bnocjwomgfjykgkm")
    public suspend fun appList(`value`: Output<List<EnrolledIntuneAppArgs>>) {
        this.appList = value
    }

    @JvmName("nxponvxcfwsvsiop")
    public suspend fun appList(vararg values: Output<EnrolledIntuneAppArgs>) {
        this.appList = Output.all(values.asList())
    }

    /**
     * @param values The enrolled Intune apps.
     */
    @JvmName("xsasdrxjwaxmxuhk")
    public suspend fun appList(values: List<Output<EnrolledIntuneAppArgs>>) {
        this.appList = Output.all(values)
    }

    /**
     * @param value The id of the Intune enrollment credential.
     */
    @JvmName("xtwuoouopudbdijn")
    public suspend fun credentialId(`value`: Output<String>) {
        this.credentialId = value
    }

    /**
     * @param value The expected duration of Intune applications and policies deployment.
     */
    @JvmName("cqgcbvxisnelywmg")
    public suspend fun expectedDeploymentDurationInMinute(`value`: Output<Int>) {
        this.expectedDeploymentDurationInMinute = value
    }

    /**
     * @param value The enrolled Intune apps.
     */
    @JvmName("wklnggmoxjcluune")
    public suspend fun appList(`value`: List<EnrolledIntuneAppArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.appList = mapped
    }

    /**
     * @param argument The enrolled Intune apps.
     */
    @JvmName("moneocwfkiqbmgxt")
    public suspend fun appList(argument: List<suspend EnrolledIntuneAppArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            EnrolledIntuneAppArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.appList = mapped
    }

    /**
     * @param argument The enrolled Intune apps.
     */
    @JvmName("migkqqjwhxdkamam")
    public suspend fun appList(vararg argument: suspend EnrolledIntuneAppArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            EnrolledIntuneAppArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.appList = mapped
    }

    /**
     * @param argument The enrolled Intune apps.
     */
    @JvmName("cgcgjdjpcixqnetb")
    public suspend fun appList(argument: suspend EnrolledIntuneAppArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(EnrolledIntuneAppArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.appList = mapped
    }

    /**
     * @param values The enrolled Intune apps.
     */
    @JvmName("fobfuydsjxaywite")
    public suspend fun appList(vararg values: EnrolledIntuneAppArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.appList = mapped
    }

    /**
     * @param value The id of the Intune enrollment credential.
     */
    @JvmName("jcjvcbbjvxyqeqvw")
    public suspend fun credentialId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.credentialId = mapped
    }

    /**
     * @param value The expected duration of Intune applications and policies deployment.
     */
    @JvmName("umdigpdngwfcdowd")
    public suspend fun expectedDeploymentDurationInMinute(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.expectedDeploymentDurationInMinute = mapped
    }

    internal fun build(): IntuneEnrollmentMetadataArgs = IntuneEnrollmentMetadataArgs(
        appList = appList,
        credentialId = credentialId,
        expectedDeploymentDurationInMinute = expectedDeploymentDurationInMinute,
    )
}
